// src/firebase/database.js
import { getFirestore, collection, addDoc, onSnapshot, query, orderBy } from "firebase/firestore";
import app from "./firebaseConfig";

const db = getFirestore(app);
const messagesRef = collection(db, "messages");

// Fungsi untuk mengirim pesan
export const sendMessage = async (text) => {
  try {
    const user = JSON.parse(localStorage.getItem("user"));
    if (!user) return;

    await addDoc(messagesRef, {
      text,
      sender: user.displayName,
      uid: user.uid,
      timestamp: new Date(),
    });
  } catch (error) {
    console.error("Error adding message: ", error);
  }
};

// Mendengarkan pesan secara real-time
export const listenForMessages = (callback) => {
  const q = query(messagesRef, orderBy("timestamp"));
  onSnapshot(q, (snapshot) => {
    const messages = snapshot.docs.map((doc) => ({
      id: doc.id,
      ...doc.data(),
    }));
    callback(messages);
  });
};
